# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "1.0.2"
FULL_VERSION = "1.0.2.1.0.0"

ARCHIVES_BASE_NAME = "hierophantics"
CARDINAL_COMPONENTS_VERSION = "5.2.1"
CLOTH_CONFIG_VERSION = "11.1.118"
FABRIC_API_VERSION = "0.92.2+1.20.1"
FABRIC_KOTLIN_VERSION = "1.10.10+kotlin.1.9.10"
HEXCASTING_VERSION = "0.11.2-pre-702"
INLINE_VERSION = "1.0.2-51"
KOTLIN_STDLIB_DEFAULT_DEPENDENCY = "false"
LOADER_VERSION = "0.16.7"
MAVEN_GROUP = "robotgiggle.hierophantics"
MINECRAFT_VERSION = "1.20.1"
MOD_VERSION = "1.0.2"
ORG_GRADLE_JVMARGS = "-Xmx1G"
ORG_GRADLE_PARALLEL = "true"
PATCHOULI_VERSION = "84"
PAUCAL_VERSION = "0.6.0-pre-118"
YARN_MAPPINGS = "1.20.1+build.10"
